@@ -1,11 +1,10 @@
-// Copyright 2020 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
-// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
-// http://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
-// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
-// modified, or distributed except according to those terms. Please review the Licences for the
-// specific language governing permissions and limitations relating to use of the SAFE Network
-// Software.
+// This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
+// Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
+// under the GPL Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied. Please review the Licences for the specific language governing
+// permissions and limitations relating to use of the SAFE Network Software.
 
 use assert_cmd::prelude::*;
 use assert_fs::prelude::*;
@@ -56,14 +55,14 @@ fn calling_safe_cat_using_spot_file() -> Result<()> {
         safeurl.content_type(),
         ContentType::MediaType("text/markdown".to_string())
     );
-    assert_eq!(safeurl.data_type(), DataType::Bytes);
+    assert_eq!(safeurl.data_type(), DataType::File);
     Ok(())
 }
 
-/// A 'blob' file is one that's larger than 3072 bytes in size.
-/// These use self encryption and are stored in a different way from 'spot' files.
+/// A 'large' file is one that's larger than 3072 bytes in size.
+/// These use self encryption and are stored in a different way from 'small' files.
 #[test]
-fn calling_safe_cat_using_blob_file() -> Result<()> {
+fn calling_safe_cat_using_large_file() -> Result<()> {
     let output = safe_cmd_stdout(
         [
             "files",
@@ -96,7 +95,7 @@ fn calling_safe_cat_using_blob_file() -> Result<()> {
         safeurl.content_type(),
         ContentType::MediaType("text/markdown".to_string())
     );
-    assert_eq!(safeurl.data_type(), DataType::Bytes);
+    assert_eq!(safeurl.data_type(), DataType::File);
     Ok(())
 }
 
@@ -165,7 +164,7 @@ fn calling_safe_cat_hexdump() -> Result<()> {
         safeurl.content_type(),
         ContentType::MediaType("text/markdown".to_string())
     );
-    assert_eq!(safeurl.data_type(), DataType::Bytes);
+    assert_eq!(safeurl.data_type(), DataType::File);
     Ok(())
 }
 
